Struct motion_lib::mlist::Extra
source · pub struct Extra {
pub xlu_start: u8,
pub xlu_end: u8,
pub cancel_frame: u8,
pub no_stop_intp: bool,
}Fields
xlu_start: u8xlu_end: u8cancel_frame: u8no_stop_intp: boolTrait Implementations
sourceimpl<'de> Deserialize<'de> for Extra
impl<'de> Deserialize<'de> for Extra
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Diff for Extra
impl Diff for Extra
sourcefn diff_custom<D>(&self, other: &Self, visitor: &D) -> <D as Differ<Self>>::Reprwhere
D: Differ<Self>,
fn diff_custom<D>(&self, other: &Self, visitor: &D) -> <D as Differ<Self>>::Reprwhere
D: Differ<Self>,
Produces a diff between two structs, using an external diffing implementation
sourcefn apply_custom<D>(&mut self, diff: &<D as Differ<Self>>::Repr, visitor: &D)where
D: Differ<Self>,
fn apply_custom<D>(&mut self, diff: &<D as Differ<Self>>::Repr, visitor: &D)where
D: Differ<Self>,
Applies the diff directly to the struct, using an external diffing implementation
impl StructuralPartialEq for Extra