Struct motion_lib::mlist::Flags
source · [−]pub struct Flags {
pub turn: bool,
pub loop: bool,
pub move: bool,
pub fix_trans: bool,
pub fix_rot: bool,
pub fix_scale: bool,
pub unk_40: bool,
pub unk_80: bool,
pub unk_100: bool,
pub unk_200: bool,
pub unk_400: bool,
}Fields
turn: boolloop: boolmove: boolfix_trans: boolfix_rot: boolfix_scale: boolunk_40: boolunk_80: boolunk_100: boolunk_200: boolunk_400: boolTrait Implementations
sourceimpl<'de> Deserialize<'de> for Flags
impl<'de> Deserialize<'de> for Flags
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Diff for Flags
impl Diff for Flags
sourcefn diff_custom<D>(&self, other: &Self, visitor: &D) -> <D as Differ<Self>>::Repr where
D: Differ<Self>,
fn diff_custom<D>(&self, other: &Self, visitor: &D) -> <D as Differ<Self>>::Repr where
D: Differ<Self>,
Produces a diff between two structs, using an external diffing implementation
sourcefn apply_custom<D>(&mut self, diff: &<D as Differ<Self>>::Repr, visitor: &D) where
D: Differ<Self>,
fn apply_custom<D>(&mut self, diff: &<D as Differ<Self>>::Repr, visitor: &D) where
D: Differ<Self>,
Applies the diff directly to the struct, using an external diffing implementation
impl Copy for Flags
impl StructuralPartialEq for Flags