Struct motion_lib::mlist::MList
source · [−]Fields
motion_path: Hash40list: IndexMap<Hash40, Motion>Trait Implementations
sourceimpl<'de> Deserialize<'de> for MList
impl<'de> Deserialize<'de> for MList
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Diff for MList
impl Diff for MList
sourcefn diff_custom<D>(&self, other: &Self, visitor: &D) -> <D as Differ<Self>>::Repr where
D: Differ<Self>,
fn diff_custom<D>(&self, other: &Self, visitor: &D) -> <D as Differ<Self>>::Repr where
D: Differ<Self>,
Produces a diff between two structs, using an external diffing implementation
sourcefn apply_custom<D>(&mut self, diff: &<D as Differ<Self>>::Repr, visitor: &D) where
D: Differ<Self>,
fn apply_custom<D>(&mut self, diff: &<D as Differ<Self>>::Repr, visitor: &D) where
D: Differ<Self>,
Applies the diff directly to the struct, using an external diffing implementation